/**
 * Vezbe 6
 * Preduslov predavanja zakljucno sa Mape i skupovi
 * Klasa Firma modelira gradj. firmu
 */
import java.util.ArrayList;
import java.util.HashMap;
public class Firma
{
    private String ime;
    private String adresa;
    private ArrayList<Projektant> projektanti; // projektanti u firmi
    private ArrayList<Projekat> projekti;      // aktivni projekti u firmi
    
    /**
     * Kreira firmu
     */
    public Firma(String ime, String adresa){
        this.ime = ime;
        this.adresa = adresa;
        projekti = new ArrayList<>();
        projektanti = new ArrayList<>();
    }
    /**
     * Vraca ime
     */
    public String dajIme() { return ime; }
    /**
     * Vraca adresu
     */
    public String dajAdresu() { return adresa; }
    /**
     * Postavlja ime
     */
    public void postaviIme(String ime){
        this.ime = ime;
    }
    /**
     * Postavlja adresu
     */
    public void postaviAdresu(String adresa){
        this.adresa = adresa;
    }
    /**
     * Dodaj projektanta u firmu
     */
    public void dodajProjektanta(Projektant p){ 
        projektanti.add(p);
    }
    /**
     * Ukloni projektanta iz firme
     */
    public void ukloniProjektanta(Projektant p){ 
        projektanti.remove(p);
    }
    /**
     * Vrati projektanta sa imenom i prezimenom (pretpostavka nema dva ista imena i prezimena)
     */
    public Projektant dajProjektanta(String ime, String prezime){
        for(Projektant p : projektanti){
            if(p.dajIme().equals(ime) && p.dajPrezime().equals(prezime)){
                return p;
            }
        }
        return null; // nema trazenog projektanta
    }
    /**
     * Vrati projekat sa imenom (pretpostavka nema dva ista imena )
     */
    public Projekat dajProjekat(String ime){
        for(Projekat p : projekti){
            if(p.dajIme().equals(ime)){
                return p;
            }
        }
        return null; // nema trazenog projekta
    }    
    /**
     * Dodaj projekat u firmu
     */
    public void dodajProjekat(Projekat p){ 
        projekti.add(p);
    }
    /**
     * Ukloni projekat iz firme
     */
    public void ukloniProjekat(Projekat p){ 
        projekti.remove(p);
    }
    /**
     * Stampa sve projektante u firmi 
     */
    public void sviProjektanti(){
        for(Projektant p : projektanti){
            p.info();
        }   
    }      
    /**
     * Vraca mapu projektant - projekti na kojima je angazovan 
     */
    public HashMap<Projektant, ArrayList<Projekat>> projektantiPoProjektima(){
        HashMap<Projektant, ArrayList<Projekat>> mapa = new HashMap<>();
        for(Projektant p : projektanti){
            ArrayList<Projekat> pProjekti = new ArrayList<>();
            for(Projekat projekat : projekti){
                if(projekat.dajGlavnog() == p || 
                    projekat.dajProjektante().contains(p)) {
                    pProjekti.add(projekat);
                }
            }
            mapa.put(p, pProjekti);
        }
        return mapa;
    }
    /**
     * Sortiraj i vrati projektante po plati
     */
    public Projektant[] sortiraPlate(){ 
        
        //double[] plate = new double[projektanti.size()];
        Projektant[] sortirani = new Projektant[projektanti.size()];
        
        /////////////////////////////////////
        int i = 0;
        for(Projektant p : projektanti){
            //plate[i] = p.dajPlatu();
            sortirani[i] = p;
            i++;
        }
        ///////////////////////////////////////
        for(i = 0; i < projektanti.size() - 1; i++){
            for(int j = i+1; j < projektanti.size(); j++){
                //if(plate[i] > plate[j]){
                if(sortirani[i].dajPlatu() > sortirani[j].dajPlatu()){    
                    //double k = plate[i];
                    Projektant p = sortirani[i];
                    //plate[i] = plate[j];
                    sortirani[i] = sortirani[j];
                    //plate[j] = k;
                    sortirani[j] = p;
                }
            }
        }
        ///////////////////////////////////////////////
        return sortirani;
    }
    
    public static void test() {
        
        Projektant a = new Projektant("A", "A"); a.postaviPlatu(100);
        Projektant b= new Projektant("B", "B"); b.postaviPlatu(10);
        
        Firma f = new Firma("GRF", "BKA73");
        
        f.dodajProjektanta(a); f.dodajProjektanta(b);
        f.sviProjektanti();
        
        System.out.println("\n\nPosle sortiranja \n\n\n");
        
        for(Projektant p : f.sortiraPlate()) {
            p.info();
        }
        
    }
    
}
